%BREAST 699 objects with 9 features in 2 classes
%
%       X = BREAST
%
% Breast cancer Wisconsin dataset obtained from the University of Wisconsin
% Hospitals, Madison from Dr. William H. Wolberg.
%
% REFERENCE
% O. L. Mangasarian and W. H. Wolberg: "Cancer diagnosis via linear 
% programming", SIAM News, Volume 23, Number 5, September 1990, pp 1 & 18.
%
%       X = BREAST(VAL)
%
% By default objects with missing values are removed. When something else
% is desired, use one of the options in MISVAL for VAL.
%
% SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
% PRTOOLS, DATASETS, MISVAL

% Copyright: R.P.W. Duin 

function a = breast(val)

if nargin < 1, val = 'remove'; end

a = pr_loadmatfile;
if isempty(a)
  opt.delimeter = ',';
  opt.labfeat   = 11;
  opt.featnames = {'Clump Thickness' 'Uniformity of Cell Size' ...
    'Uniformity of Cell Shape' 'Marginal Adhesion' ...
    'Single Epithelial Cell Size' 'Bare Nuclei' 'Bland Chromatin' ...
    'Normal Nucleoli' 'Mitoses'};
  opt.feats = [2:10];
  opt.misvalue = -1;
  opt.classnames = {'benign' 'malignant'};
  opt.desc='The original database of the Wisconsin Breast Cancer Databases from UCI, containing 699 instances, collected between 1989 and 1991. ';
  opt.link = 'ftp://ftp.ics.uci.edu/pub/machine-learning-databases/breast-cancer-wisconsin/';
  opt.dsetname = 'Breast Wisconsin';
  a = pr_download('http://prtools.tudelft.nl/prdatasets/breastorg.dat',[],opt);
end
a = misval(a,val);

return
